@@ -515,7 +515,14 @@ var GraphDataWindow = {
       hideHeaders: true,
       width: 385,
       height: 140,
-      columns: [ {header: 'Graph Targets', width: 1.0, dataIndex: 'value'} ],
+      columns: [
+        {
+          header: 'Graph Targets',
+          width: 1.0,
+          dataIndex: 'value',
+          tpl: '{value:htmlEncode}'
+        }
+      ],
       listeners: {
         contextmenu: this.targetContextMenu,
         afterrender: this.targetChanged,
@@ -1074,8 +1081,10 @@ function createFunctionsMenu() {
       text: 'Combine',
       menu: [
         {text: 'Sum', handler: applyFuncToAll('sumSeries')},
+        {text: 'Sum (of series lists)', handler: applyFuncToAll('sumSeriesLists')},
         {text: 'Average', handler: applyFuncToAll('averageSeries')},
         {text: 'Product', handler: applyFuncToAll('multiplySeries')},
+        {text: 'Product (of series lists)', handler: applyFuncToAll('multiplySeriesLists')},
         {text: 'Min Values', handler: applyFuncToAll('minSeries')},
         {text: 'Max Values', handler: applyFuncToAll('maxSeries')},
         {text: 'Group', handler: applyFuncToAll('group')},
@@ -1085,28 +1094,32 @@ function createFunctionsMenu() {
     }, {
       text: 'Transform',
       menu: [
-        {text: 'Scale', handler: applyFuncToEachWithInput('scale', 'Please enter a scale factor')},
-        {text: 'ScaleToSeconds', handler: applyFuncToEachWithInput('scaleToSeconds', 'Please enter a number of seconds to scale to')},
-        {text: 'Offset', handler: applyFuncToEachWithInput('offset', 'Please enter the value to offset Y-values by')},
-        {text: 'OffsetToZero', handler: applyFuncToEach('offsetToZero')},
-        {text: 'Interpolate', handler: applyFuncToEach('interpolate')},
-        {text: 'Derivative', handler: applyFuncToEach('derivative')},
-        {text: 'Power', handler: applyFuncToEachWithInput('pow', 'Please enter a power factor')},
-        {text: 'Power Series', handler: applyFuncToEachWithInput('powSeries', 'Please enter at least 2 series')},
-        {text: 'Square Root', handler: applyFuncToEach('squareRoot')},
-        {text: 'Time-adjusted Derivative', handler: applyFuncToEachWithInput('perSecond', 'Please enter a maximum value if this metric is a wrapping counter (or just leave this blank)', {allowBlank: true})},
+        {text: 'Absolute Value', handler: applyFuncToEach('absolute')},
+        {text: 'Add', handler: applyFuncToEachWithInput('add', 'Please enter a constant')},
         {text: 'Delay', handler: applyFuncToEachWithInput('delay', 'Please enter the number of steps to delay')},
+        {text: 'Derivative', handler: applyFuncToEach('derivative')},
+        {text: 'Exp', handler: applyFuncToEach('exp')},
+        {text: 'Hit Count', handler: applyFuncToEachWithInput('hitcount', 'Please enter a summary interval (examples: 10min, 1h, 7d)', {quote: true})},
+        {text: 'Interpolate', handler: applyFuncToEach('interpolate')},
         {text: 'Integral', handler: applyFuncToEach('integral')},
         {text: 'Integral by Interval', handler: applyFuncToEachWithInput('integralByInterval', 'Integral this metric with a reset every ___ (examples: 1d, 1h, 10min)', {quote: true})},
-        {text: 'Percentile Values', handler: applyFuncToEachWithInput('percentileOfSeries', 'Please enter the percentile to use')},
-        {text: 'Non-negative Derivative', handler: applyFuncToEachWithInput('nonNegativeDerivative', 'Please enter a maximum value if this metric is a wrapping counter (or just leave this blank)', {allowBlank: true})},
-        {text: 'Log', handler: applyFuncToEachWithInput('log', 'Please enter a base')},
         {text: 'Invert', handler: applyFuncToEach('invert')},
-        {text: 'Absolute Value', handler: applyFuncToEach('absolute')},
+        {text: 'Log', handler: applyFuncToEachWithInput('log', 'Please enter a base')},
+        {text: 'Logit', handler: applyFuncToEach('logit')},
+        {text: 'Non-negative Derivative', handler: applyFuncToEachWithInput('nonNegativeDerivative', 'Please enter a maximum value if this metric is a wrapping counter (or just leave this blank)', {allowBlank: true})},
+        {text: 'Offset', handler: applyFuncToEachWithInput('offset', 'Please enter the value to offset Y-values by')},
+        {text: 'OffsetToZero', handler: applyFuncToEach('offsetToZero')},
+        {text: 'Percentile Values', handler: applyFuncToEachWithInput('percentileOfSeries', 'Please enter the percentile to use')},
+        {text: 'Power', handler: applyFuncToEachWithInput('pow', 'Please enter a power factor')},
+        {text: 'Power Series', handler: applyFuncToEachWithInput('powSeries', 'Please enter at least 2 series')},
+        {text: 'Summarize', handler: applyFuncToEachWithInput('summarize', 'Please enter a summary interval (examples: 10min, 1h, 7d)', {quote: true})},
+        {text: 'Scale', handler: applyFuncToEachWithInput('scale', 'Please enter a scale factor')},
+        {text: 'ScaleToSeconds', handler: applyFuncToEachWithInput('scaleToSeconds', 'Please enter a number of seconds to scale to')},
+        {text: 'Sigmoid', handler: applyFuncToEach('sigmoid')},
+        {text: 'Square Root', handler: applyFuncToEach('squareRoot')},
         {text: 'timeShift', handler: applyFuncToEachWithInput('timeShift', 'Shift this metric ___ back in time (examples: 10min, 7d, 2w)', {quote: true})},
         {text: 'timeSlice', handler: applyFuncToEachWithInput('timeSlice', 'Start showing metric at (example: 14:57 20150115)', {quote: true})},
-        {text: 'Summarize', handler: applyFuncToEachWithInput('summarize', 'Please enter a summary interval (examples: 10min, 1h, 7d)', {quote: true})},
-        {text: 'Hit Count', handler: applyFuncToEachWithInput('hitcount', 'Please enter a summary interval (examples: 10min, 1h, 7d)', {quote: true})}
+        {text: 'Time-adjusted Derivative', handler: applyFuncToEachWithInput('perSecond', 'Please enter a maximum value if this metric is a wrapping counter (or just leave this blank)', {allowBlank: true})}
       ]
     }, {
       text: 'Calculate',
@@ -1123,6 +1136,7 @@ function createFunctionsMenu() {
         {text: 'Linear Regression', handler: applyFuncToEachWithInput('linearRegression', 'Start source of regression at (example: 14:57 20150115)', {quote: true})},
         {text: 'As Percent', handler: applyFuncToEachWithInput('asPercent', 'Please enter the value that corresponds to 100% or leave blank to use the total', {allowBlank: true})},
         {text: 'Difference (of 2 series)', handler: applyFuncToAll('diffSeries')},
+        {text: 'Difference (of series lists)', handler: applyFuncToAll('diffSeriesLists')},
         {text: 'Ratio (of 2 series)', handler: applyFuncToAll('divideSeries')},
         {text: 'Ratio (of series lists)', handler: applyFuncToAll('divideSeriesLists')},
         {text: 'Exponential Moving Average', handler: applyFuncToEachWithInput('exponentialMovingAverage', 'EMA for the last __ data points')}
